@@ -46,6 +46,8 @@ static gboolean have_mmx;
 static gboolean have_sse41;
 static gboolean have_popcnt;
 
+static gint n_threads = -1;
+
 static void
 init_features (void)
 {
@@ -180,3 +182,56 @@ chafa_describe_features (ChafaFeatures features)
 
     return g_string_free (features_gstr, FALSE);
 }
+
+/**
+ * chafa_get_n_threads:
+ *
+ * Queries the maximum number of worker threads to use for parallel processing.
+ *
+ * Returns: The number of threads, or -1 if determined automatically
+ **/
+gint
+chafa_get_n_threads (void)
+{
+    return g_atomic_int_get (&n_threads);
+}
+
+/**
+ * chafa_set_n_threads:
+ * @n: Number of threads
+ *
+ * Sets the maximum number of worker threads to use for parallel processing,
+ * or -1 to determine this automatically. The default is -1.
+ *
+ * Setting this to 0 or 1 will avoid using thread pools and instead perform
+ * all processing in the main thread.
+ **/
+void
+chafa_set_n_threads (gint n)
+{
+    g_return_if_fail (n >= -1);
+
+    return g_atomic_int_set (&n_threads, n);
+}
+
+/**
+ * chafa_get_n_actual_threads:
+ *
+ * Queries the number of worker threads that will actually be used for
+ * parallel processing.
+ *
+ * Returns: Number of threads, always >= 1
+ **/
+gint
+chafa_get_n_actual_threads (void)
+{
+    gint n_threads;
+
+    n_threads = chafa_get_n_threads ();
+    if (n_threads < 0)
+        n_threads = g_get_num_processors ();
+    if (n_threads <= 0)
+        n_threads = 1;
+
+    return n_threads;
+}
