@@ -45,17 +45,28 @@ struct ChafaCanvas
     ChafaCanvasCell *cells;
     guint have_alpha : 1;
     guint needs_clear : 1;
-    ChafaColor fg_color;
-    ChafaColor bg_color;
+
+    /* Whether to consider inverted symbols; FALSE if using FG only */
+    guint consider_inverted : 1;
+
+    /* Whether to extract symbol colors; FALSE if using default colors */
+    guint extract_colors : 1;
+
+    ChafaColorPair default_colors;
     guint work_factor_int;
 
+    /* Character to use in cells where fg color == bg color. Typically
+     * space, but could be something else depending on the symbol map. */
+    gunichar blank_char;
+
     ChafaCanvasConfig config;
 
     /* Used when setting pixel data */
     ChafaDither dither;
 
-    /* Set if we're in sixel mode */
-    ChafaSixelCanvas *sixel_canvas;
+    /* This is NULL in CHAFA_PIXEL_MODE_SYMBOLS, otherwise one of:
+     * (ChafaSixelCanvas *), (ChafaKittyCanvas *), (ChafaIterm2Canvas *) */
+    gpointer pixel_canvas;
 
     /* Our palette. Kind of a big structure, so it goes last. */
     ChafaPalette palette;
